@@ -54,7 +54,7 @@ namespace {
 			const auto dir = realpath(reldir.c_str(), nullptr);
 			if(!dir) {
 				fmt::print(stderr, "\n");
-				return fmt::format("Getting realpath for {}: {}", reldir, strerror(errno));
+				return fmt::format("Getting realpath for {}: {}", reldir, std::strerror(errno));
 			}
 			klapki::quickscope_wrapper dir_deleter{[&] { std::free(dir); }};
 
