@@ -79,7 +79,7 @@ std::optional<std::string> klapki::context::context::save(const config & cfg, st
 			   size >= 0)
 				esp_devpath_raw.resize(size);
 			else if(errno != ENOSPC)
-				return fmt::format("Making device path for ESP: {}", strerror(errno));
+				return fmt::format("Making device path for ESP: {}", std::strerror(errno));
 		} while(errno == ENOSPC);
 
 
@@ -128,11 +128,11 @@ std::optional<std::string> klapki::context::context::save(const config & cfg, st
 
 		std::vector<std::uint8_t> devpath_file_node(efidp_make_file(nullptr, 0, image_path.data()));
 		if(efidp_make_file(devpath_file_node.data(), devpath_file_node.size(), image_path.data()) < 0)
-			return fmt::format("Entry {:04X}: creating devpath File(): {}", bootnum, strerror(errno));
+			return fmt::format("Entry {:04X}: creating devpath File(): {}", bootnum, std::strerror(errno));
 
 		efidp_data * devpath;
 		if(efidp_append_node(esp_devpath, reinterpret_cast<const efidp_data *>(devpath_file_node.data()), &devpath) < 0)
-			return fmt::format("Entry {:04X}: creating appending File(): {}", bootnum, strerror(errno));
+			return fmt::format("Entry {:04X}: creating appending File(): {}", bootnum, std::strerror(errno));
 		quickscope_wrapper devpath_deleter{[&] { std::free(devpath); }};
 		const auto devpath_len = efidp_size(devpath);
 
@@ -155,7 +155,7 @@ std::optional<std::string> klapki::context::context::save(const config & cfg, st
 
 		std::vector<std::uint16_t> cmdline(utf8len(reinterpret_cast<std::uint8_t *>(templine.data()), templine.size()));
 		if(utf8_to_ucs2(cmdline.data(), cmdline.size() * sizeof(std::uint16_t), false, reinterpret_cast<std::uint8_t *>(templine.data())) < 0)
-			return fmt::format("Entry {:04X}: UCS-2ing cmdline: {}", bootnum, strerror(errno));
+			return fmt::format("Entry {:04X}: UCS-2ing cmdline: {}", bootnum, std::strerror(errno));
 
 		// extern ssize_t efi_loadopt_create(uint8_t *buf, ssize_t size,
 		//				  uint32_t attributes, efidp dp,
@@ -174,7 +174,7 @@ std::optional<std::string> klapki::context::context::save(const config & cfg, st
 		                      devpath, devpath_len,                                          //
 		                      reinterpret_cast<unsigned char *>(kern.description.data()),    //
 		                      reinterpret_cast<std::uint8_t *>(cmdline.data()), cmdline.size() * sizeof(std::uint16_t)) < 0)
-			return fmt::format("Making load option for {:04X}: {}", bootnum, strerror(errno));
+			return fmt::format("Making load option for {:04X}: {}", bootnum, std::strerror(errno));
 
 		SHA1(bent->second.load_option.get(), bent->second.load_option_len, bent->second.load_option_sha);
 		if(std::memcmp(bent->second.load_option_sha, skern->load_option_sha, sizeof(sha_t)))
