@@ -115,13 +115,13 @@ std::variant<klapki::state::state, std::string> klapki::state::state::load(std::
 		   else if(is_our_config(guid, name, us))
 			   have_our_config = true;
 	   }))
-		return fmt::format("EFI load: iteration: {}", strerror(res));  // No threads here, and we avoid a strerror_r() clusterfuck
+		return fmt::format("EFI load: iteration: {}", std::strerror(res));  // No threads here, and we avoid a strerror_r() clusterfuck
 
 
 	boot_order_flat bord{};
 	if(have_boot_order) {
 		if(get_boot_order(bord) < 0)
-			return fmt::format("EFI load: getting BootOrder: {}", strerror(errno));
+			return fmt::format("EFI load: getting BootOrder: {}", std::strerror(errno));
 	} else
 		fmt::print(stderr, "EFI: no BootOrder?\n");
 
@@ -129,13 +129,13 @@ std::variant<klapki::state::state, std::string> klapki::state::state::load(std::
 	std::map<std::uint16_t, boot_entry> entries;
 	for(auto bent : boot_entries)
 		if(get_boot_entry(entries, bent) < 0)
-			return fmt::format("EFI load: getting Boot{:04X}: {}", bent, strerror(errno));
+			return fmt::format("EFI load: getting Boot{:04X}: {}", bent, std::strerror(errno));
 
 
 	stated_config statecfg{};
 	if(have_our_config) {
 		if(get_our_config(statecfg, us) < 0)
-			return fmt::format("EFI load: getting {}-{}: {}", efi_guid_klapki_s, us, strerror(errno));
+			return fmt::format("EFI load: getting {}-{}: {}", efi_guid_klapki_s, us, std::strerror(errno));
 	} else
 		fmt::print(stderr, "EFI load: no config for this host ({}) found; going to the top\n", us);
 
